BenchGroup

Struct BenchGroup 

pub struct BenchGroup<'routine> { /* private fields */ }
One group of a stated bench: what the cases are compared within, and the cases.

Implementations

Source

impl<'routine> BenchGroup<'routine>

pub const fn new(group: &'static str, cases: BenchCases<'routine>) -> Self

States cases as one group, named group.

pub const fn group(&self) -> &'static str

Returns what the group is named.

pub fn cases(self) -> BenchCases<'routine>

Returns the cases the group states, and how they are measured.

pub const fn stated(&self) -> &BenchCases<'routine>

Reads the cases the group states without taking them.