BenchStated

Struct BenchStated 

pub struct BenchStated<'routine> { /* private fields */ }
A stated bench: its groups, in the order stated.

Implementations

Source

impl<'routine> BenchStated<'routine>

pub const fn new() -> Self

States a bench of no groups.

pub fn group(self, group: BenchGroup<'routine>) -> Self

States one group after the groups already stated.

pub fn then(self, next: Self) -> Self

States the groups of next after the groups of this bench.

pub fn groups(&self) -> impl Iterator<Item = &BenchGroup<'routine>>

Reads the groups the bench states, in the order stated.

pub fn into_groups(self) -> impl Iterator<Item = BenchGroup<'routine>>

Separates the groups from the bench that states them.