pub struct BenchStated<'routine> { /* private fields */ }Expand description
A stated bench: its groups, in the order stated.
Implementations
Sourceimpl<'routine> BenchStated<'routine>
impl<'routine> BenchStated<'routine>
Sourcepub fn group(self, group: BenchGroup<'routine>) -> Self
pub fn group(self, group: BenchGroup<'routine>) -> Self
States one group after the groups already stated.
Sourcepub fn then(self, next: Self) -> Self
pub fn then(self, next: Self) -> Self
States the groups of next after the groups of this bench.
Sourcepub fn groups(&self) -> impl Iterator<Item = &BenchGroup<'routine>>
pub fn groups(&self) -> impl Iterator<Item = &BenchGroup<'routine>>
Reads the groups the bench states, in the order stated.
Sourcepub fn into_groups(self) -> impl Iterator<Item = BenchGroup<'routine>>
pub fn into_groups(self) -> impl Iterator<Item = BenchGroup<'routine>>
Separates the groups from the bench that states them.